'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-64113c20.js');
const index_esm_min$1 = require('./index.esm.min-d6127cb6.js');
const index_esm_min = require('./index.esm.min-8bc5517a.js');

const bpSdkQuestionGroupCss = ".bp-sdk-row{display:flex;flex-direction:row}.bp-sdk-column{display:flex;flex-direction:column}.bp-sdk-space-between{justify-content:space-between}";

const BpSdkQuestionGroup = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.answers = [];
    this.classes = '';
    this.label = undefined;
    this.labelId = index_esm_min.fx(8);
    this.questionGroup = undefined;
    this.type = undefined;
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-question-group');
    customElements.whenDefined('bp-sdk-external-question-group').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderUnknownGroupType(answer) {
    var _a;
    const nestedGroupToRender = (_a = this.questionGroup.nestedGroupsWithAnswers) === null || _a === void 0 ? void 0 : _a.get(answer.id);
    return [
      !nestedGroupToRender && (index.h("bp-sdk-dynamic-input-redux-container", { answer: answer, labelledBy: this.label ? this.labelId : '', id: `bp-sdk-question-group__${answer.question.id}`, class: "bp-sdk-question-group__question-set" })),
      nestedGroupToRender && index.h("bp-sdk-question-group-container", { questionGroup: nestedGroupToRender }),
    ];
  }
  renderExternal() {
    return (index.h("bp-sdk-external-question-group", { answers: this.answers, classes: this.classes, label: this.label, labelId: this.labelId, questionGroup: this.questionGroup, type: this.type }));
  }
  shouldRenderLabel() {
    // Adding a check to avoid accordion and coverage groups double rendering labels
    // this can likely be expanded to other group types
    return this.label && this.type !== index_esm_min$1.O.Accordion && this.type !== index_esm_min$1.O.Coverage;
  }
  renderInternal() {
    return [
      this.shouldRenderLabel() && index.h("bp-sdk-question-group-label", { labelId: this.labelId, label: this.label }),
      index.h("div", { class: this.classes }, this.renderContent()),
    ];
  }
  renderContent() {
    switch (this.type) {
      case index_esm_min$1.O.Address:
        return index.h("bp-sdk-address-group", { label: this.label, labelledBy: this.labelId, answers: this.answers });
      case index_esm_min$1.O.AccumulatePercentage:
        return index.h("bp-sdk-accumulation-question-group-container", { label: this.label, labelledBy: this.labelId, answers: this.answers });
      case index_esm_min$1.O.Vehicle:
        return index.h("bp-sdk-vehicle-question-pool-container", { questionGroup: this.questionGroup });
      case index_esm_min$1.O.Driver:
        return index.h("bp-sdk-driver-question-pool-container", { questionGroup: this.questionGroup });
      case index_esm_min$1.O.Stepper:
        return index.h("bp-sdk-stepper-group-container", { questionGroup: this.questionGroup });
      case index_esm_min$1.O.Accordion:
        return index.h("bp-sdk-accordion", { questionGroup: this.questionGroup });
      case index_esm_min$1.O.Coverage:
        return index.h("bp-sdk-coverage-group", { questionGroup: this.questionGroup });
      default:
        return this.answers.map((answer) => this.renderUnknownGroupType(answer));
    }
  }
};
BpSdkQuestionGroup.style = bpSdkQuestionGroupCss;

const bpSdkQuestionGroupContainerCss = "";

const BpSdkQuestionGroupContainer = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.questionGroup = undefined;
    this.classes = 'bp-sdk-question-group-content';
    this.labelId = index_esm_min.fx(8);
    this.type = undefined;
    this.useExternal = false;
  }
  onQuestionGroupChange(questionGroup) {
    if (this.type !== (questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.group_type)) {
      this.type = questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.group_type;
    }
  }
  onTypeChange(type) {
    this.updateClasses(type);
  }
  resetState() {
    var _a;
    this.type = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.group_type;
  }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    var _a;
    this.useExternal = !!customElements.get('bp-sdk-external-question-group-container');
    customElements.whenDefined('bp-sdk-external-question-group-container').then(() => {
      this.useExternal = true;
    });
    this.type = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.group_type;
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return index.h("bp-sdk-external-question-group-container", { questionGroup: this.questionGroup });
  }
  renderInternal() {
    var _a, _b, _c;
    return (index.h("bp-sdk-question-group", { answers: (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.answers, classes: this.classes, label: (_b = this.questionGroup) === null || _b === void 0 ? void 0 : _b.label, labelId: this.labelId, questionGroup: this.questionGroup, type: (_c = this.questionGroup) === null || _c === void 0 ? void 0 : _c.group_type }));
  }
  updateClasses(type) {
    if (!type) {
      this.classes = 'bp-sdk-question-group-content';
      return;
    }
    this.classes = index_esm_min.ix('bp-sdk-question-group-content', {
      'bp-sdk-row': type === 'split_horizontal',
      'bp-sdk-column': type !== 'split_horizontal',
      'bp-sdk-space-between': type === 'split_horizontal',
    });
  }
  static get watchers() { return {
    "questionGroup": ["onQuestionGroupChange"],
    "type": ["onTypeChange"]
  }; }
};
BpSdkQuestionGroupContainer.style = bpSdkQuestionGroupContainerCss;

exports.bp_sdk_question_group = BpSdkQuestionGroup;
exports.bp_sdk_question_group_container = BpSdkQuestionGroupContainer;
