import { QuestionGroupType } from '@boldpenguin/sdk-types';
import { generateId } from '@boldpenguin/sdk-utility';
import { h } from '@stencil/core';
export class BpSdkQuestionGroup {
  constructor() {
    this.answers = [];
    this.classes = '';
    this.label = undefined;
    this.labelId = generateId(8);
    this.questionGroup = undefined;
    this.type = undefined;
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-question-group');
    customElements.whenDefined('bp-sdk-external-question-group').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderUnknownGroupType(answer) {
    var _a;
    const nestedGroupToRender = (_a = this.questionGroup.nestedGroupsWithAnswers) === null || _a === void 0 ? void 0 : _a.get(answer.id);
    return [
      !nestedGroupToRender && (h("bp-sdk-dynamic-input-redux-container", { answer: answer, labelledBy: this.label ? this.labelId : '', id: `bp-sdk-question-group__${answer.question.id}`, class: "bp-sdk-question-group__question-set" })),
      nestedGroupToRender && h("bp-sdk-question-group-container", { questionGroup: nestedGroupToRender }),
    ];
  }
  renderExternal() {
    return (h("bp-sdk-external-question-group", { answers: this.answers, classes: this.classes, label: this.label, labelId: this.labelId, questionGroup: this.questionGroup, type: this.type }));
  }
  shouldRenderLabel() {
    // Adding a check to avoid accordion and coverage groups double rendering labels
    // this can likely be expanded to other group types
    return this.label && this.type !== QuestionGroupType.Accordion && this.type !== QuestionGroupType.Coverage;
  }
  renderInternal() {
    return [
      this.shouldRenderLabel() && h("bp-sdk-question-group-label", { labelId: this.labelId, label: this.label }),
      h("div", { class: this.classes }, this.renderContent()),
    ];
  }
  renderContent() {
    switch (this.type) {
      case QuestionGroupType.Address:
        return h("bp-sdk-address-group", { label: this.label, labelledBy: this.labelId, answers: this.answers });
      case QuestionGroupType.AccumulatePercentage:
        return h("bp-sdk-accumulation-question-group-container", { label: this.label, labelledBy: this.labelId, answers: this.answers });
      case QuestionGroupType.Vehicle:
        return h("bp-sdk-vehicle-question-pool-container", { questionGroup: this.questionGroup });
      case QuestionGroupType.Driver:
        return h("bp-sdk-driver-question-pool-container", { questionGroup: this.questionGroup });
      case QuestionGroupType.Stepper:
        return h("bp-sdk-stepper-group-container", { questionGroup: this.questionGroup });
      case QuestionGroupType.Accordion:
        return h("bp-sdk-accordion", { questionGroup: this.questionGroup });
      case QuestionGroupType.Coverage:
        return h("bp-sdk-coverage-group", { questionGroup: this.questionGroup });
      default:
        return this.answers.map((answer) => this.renderUnknownGroupType(answer));
    }
  }
  static get is() { return "bp-sdk-question-group"; }
  static get originalStyleUrls() {
    return {
      "$": ["bp-sdk-question-group.css"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["bp-sdk-question-group.css"]
    };
  }
  static get properties() {
    return {
      "answers": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "IAnswer[]",
          "resolved": "IAnswer[]",
          "references": {
            "IAnswer": {
              "location": "import",
              "path": "@boldpenguin/sdk-types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "answers in group"
        },
        "defaultValue": "[]"
      },
      "classes": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Classes for styling group"
        },
        "attribute": "classes",
        "reflect": false,
        "defaultValue": "''"
      },
      "label": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Group label"
        },
        "attribute": "label",
        "reflect": false
      },
      "labelId": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Label id's for group"
        },
        "attribute": "label-id",
        "reflect": false,
        "defaultValue": "generateId(8)"
      },
      "questionGroup": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "IMappedQuestionGroupAnswers",
          "resolved": "IMappedQuestionGroupAnswers",
          "references": {
            "IMappedQuestionGroupAnswers": {
              "location": "import",
              "path": "@boldpenguin/sdk-types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Question Group"
        }
      },
      "type": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "group type"
        },
        "attribute": "type",
        "reflect": true
      }
    };
  }
  static get states() {
    return {
      "useExternal": {}
    };
  }
}
