import { r as registerInstance, h, c as createEvent, g as getElement } from './index-8f8983b3.js';
import { p, t } from './index.esm.min-531f07d6.js';
import { i as ix, n as bL, m as d9, Q as Q9 } from './index.esm.min-7be3b852.js';
import { removeQuestionPool, getFormId, getPartnerEngineConfig, getQuestionSets } from '@boldpenguin/sdk-redux';
import { c as canGetStore, s as store } from './store-6dda1ad2.js';

const bpSdkAccordionCss = "";

const BpSdkAccordion = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.questionGroup = undefined;
    this.useExternal = false;
  }
  resetState() { }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-accordion');
    customElements.whenDefined('bp-sdk-external-accordion').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-accordion", { questionGroup: this.questionGroup });
  }
  renderAnswer(answer) {
    var _a;
    const nestedGroupToRender = (_a = this.questionGroup.nestedGroupsWithAnswers) === null || _a === void 0 ? void 0 : _a.get(answer.id);
    return [
      !nestedGroupToRender && h("bp-sdk-dynamic-input-redux-container", { answer: answer, id: `bp-sdk-question-group__${answer.question.id}` }),
      nestedGroupToRender && h("bp-sdk-question-group-container", { questionGroup: nestedGroupToRender }),
    ];
  }
  renderInternal() {
    var _a, _b, _c;
    return (h("div", { class: "bp-sdk-accordion__container" }, h("bp-sdk-question-group-label", { labelId: (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.groupId, label: (_b = this.questionGroup) === null || _b === void 0 ? void 0 : _b.parentQuestionAnswer.question.text }), (_c = this.questionGroup) === null || _c === void 0 ? void 0 :
      _c.answers.map((answer) => this.renderAnswer(answer))));
  }
};
BpSdkAccordion.style = bpSdkAccordionCss;

const bpSdkAccumulationQuestionGroupCss = "[name='evanston_activity_inventory_percentage_total']{visibility:hidden}[name='evanston_activity_inventory_percentage_total']+bp-sdk-errors-container{display:none}";

const BpSdkAccumulationQuestionGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.answers = [];
    this.label = undefined;
    this.labelledBy = undefined;
    this.warning = 'Percent of total operations must equal 100%';
    this.accumulator = undefined;
    this.buffer = undefined;
    this.showAccumulatorWarning = false;
    this.showAccumulatorErrors = false;
    this.useExternal = false;
  }
  onAnswersChange(answers) {
    this.accumulator = (answers || []).find((answer) => { var _a; return ((_a = answer === null || answer === void 0 ? void 0 : answer.question) === null || _a === void 0 ? void 0 : _a.reference_type) === p.Accumulator; });
  }
  onAccumulatorChange(accumulator) {
    const buffer = parseInt(accumulator === null || accumulator === void 0 ? void 0 : accumulator.value, 10);
    this.buffer = isNaN(buffer) ? undefined : buffer;
    this.showAccumulatorWarning = this.validateAccumulatorValue();
  }
  onAccumulatorErrorsChange({ detail }) {
    this.showAccumulatorErrors = detail.length > 0;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-accumulation-question-group');
    customElements.whenDefined('bp-sdk-external-accumulation-question-group').then(() => {
      this.useExternal = true;
    });
    this.onAnswersChange(this.answers);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-accumulation-question-group", { answers: this.answers, label: this.label, labelledBy: this.labelledBy, warning: this.warning }));
  }
  shouldHideLabel(answer) {
    var _a, _b;
    return (((_a = answer === null || answer === void 0 ? void 0 : answer.question) === null || _a === void 0 ? void 0 : _a.field_type) === t.CheckBox || ((_b = answer === null || answer === void 0 ? void 0 : answer.question) === null || _b === void 0 ? void 0 : _b.reference_type) === p.Accumulator);
  }
  getAriaLabel(answer) {
    var _a;
    return ((_a = answer === null || answer === void 0 ? void 0 : answer.question) === null || _a === void 0 ? void 0 : _a.field_type) === t.CheckBox ? answer.question.text : undefined;
  }
  validateAccumulatorValue() {
    var _a;
    if ((_a = this.accumulator) === null || _a === void 0 ? void 0 : _a.value) {
      return this.buffer < this.accumulator.question.min_value || this.buffer > this.accumulator.question.max_value;
    }
    return false;
  }
  renderInternal() {
    var _a;
    return (h("div", { class: "bp-sdk-accumulation-question-group__container" }, h("div", { class: "bp-sdk-accumulation-question-group__wrapper" }, h("div", { class: "bp-sdk-accumulation-question-set__header" }, h("bp-sdk-progress", { label: "Question group progress", value: this.buffer }), h("div", null, ((_a = this.accumulator) === null || _a === void 0 ? void 0 : _a.value) && (h("h2", { "aria-live": "assertive", class: "bp-sdk-accumulation-question-set__value" }, this.accumulator.value, "%")), this.showAccumulatorErrors && h("h4", { class: "bp-sdk-accumulation-question-set__error" }, this.warning), this.showAccumulatorWarning && !this.showAccumulatorErrors && (h("h4", { class: "bp-sdk-accumulation-question-set__warning" }, this.warning)))), this.answers.map((answer) => (h("bp-sdk-dynamic-input-redux-container", { class: ix('', {
        'bp-sdk-indent': answer.question.reference_type === p.Indent,
      }), answer: answer, shouldHideLabel: this.shouldHideLabel(answer), "aria-label": this.getAriaLabel(answer), isAccumulatorAnswer: answer.question.reference_type === p.Accumulator }))))));
  }
  static get watchers() { return {
    "answers": ["onAnswersChange"],
    "accumulator": ["onAccumulatorChange"]
  }; }
};
BpSdkAccumulationQuestionGroup.style = bpSdkAccumulationQuestionGroupCss;

const bpSdkAccumulationQuestionGroupContainerCss = "";

const BpSdkAccumulationQuestionGroupContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.answers = undefined;
    this.label = undefined;
    this.labelledBy = undefined;
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-accumulation-question-group-container');
    customElements.whenDefined('bp-sdk-external-accumulation-question-group-container').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-accumulation-question-group-container", { answers: this.answers, label: this.label, labelledBy: this.labelledBy });
  }
  renderInternal() {
    return h("bp-sdk-accumulation-question-group", { answers: this.answers, label: this.label, labelledBy: this.labelledBy });
  }
};
BpSdkAccumulationQuestionGroupContainer.style = bpSdkAccumulationQuestionGroupContainerCss;

const bpSdkAddressGroupCss = "";

const BpSdkAddressGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.saveAnswer = createEvent(this, "saveAnswer", 7);
    this.addressMissingComponents = createEvent(this, "addressMissingComponents", 7);
    this.updateInputs = (address) => () => {
      this.updateStreet(address);
      this.updateCity(address);
      this.updateState(address);
      this.updateZip(address);
    };
    /**
     * Emits addressMissingComponents event if any required
     * address components are missing
     *
     * @param addressComponents The array of address components from Google
     */
    this.handleMissingAddressComponents = (addressComponents) => {
      const missingComponents = this.getMissingAddressComponents(addressComponents);
      if (missingComponents.length) {
        this.addressMissingComponents.emit({
          missing_components: missingComponents,
        });
      }
    };
    /**
     * Finds the address components that are missing in the Google data
     *
     * @param addressComponents The array of address components from Google
     * @returns Returns an array of missing address component types
     */
    this.getMissingAddressComponents = (addressComponents) => {
      const requiredAddressComponentTypes = ['street_number', 'route', 'locality', 'administrative_area_level_1', 'postal_code'];
      return requiredAddressComponentTypes.filter((requiredAddressComponentType) => {
        return !addressComponents.some((addressComponent) => addressComponent.types[0] === requiredAddressComponentType);
      });
    };
    this.answers = [];
    this.label = undefined;
    this.labelledBy = undefined;
    this.answerMap = {};
    this.useExternal = false;
  }
  onAnswersChange(newAnswers) {
    const map = {};
    newAnswers.forEach((answer) => {
      var _a;
      if ((_a = answer === null || answer === void 0 ? void 0 : answer.question) === null || _a === void 0 ? void 0 : _a.reference_type) {
        map[answer.question.reference_type] = answer;
      }
    });
    this.answerMap = map;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-address-group');
    customElements.whenDefined('bp-sdk-external-address-group').then(() => {
      this.useExternal = true;
    });
    this.onAnswersChange(this.answers);
  }
  emitSaveAnswer(answer, newValue) {
    this.saveAnswer.emit({
      answer,
      new_value: newValue,
    });
  }
  onPlacesUpdate({ detail }) {
    if (this.useExternal) {
      return;
    }
    const address = {};
    if (detail.address_components) {
      detail.address_components.forEach((addressComponent) => {
        address[addressComponent.types[0]] = {
          short: addressComponent.short_name,
          long: addressComponent.long_name,
        };
      });
      setTimeout(this.updateInputs(address), 0);
      this.handleMissingAddressComponents(detail.address_components);
    }
    this.updateJson(detail);
  }
  updateStreet(address) {
    if (address['street_number'] && address['route']) {
      const street_answer = this.answerMap['street_1'];
      if (street_answer) {
        this.emitSaveAnswer(Object.assign({}, street_answer), `${address['street_number'].long} ${address['route'].long}`);
      }
    }
  }
  updateCity(address) {
    if (address['locality']) {
      const city_answer = this.answerMap['city'];
      if (city_answer) {
        this.emitSaveAnswer(Object.assign({}, city_answer), address['locality'].long);
      }
    }
  }
  updateState(address) {
    if (address['administrative_area_level_1']) {
      const state_answer = this.answerMap['state'];
      if (state_answer) {
        const state = address['administrative_area_level_1'].short;
        const state_choice = state_answer.question.choices.find((choice) => choice.alias === state);
        if (state_choice) {
          this.emitSaveAnswer(Object.assign({}, state_answer), [state_choice.id]);
        }
      }
    }
  }
  updateZip(address) {
    if (address['postal_code']) {
      const zip_answer = this.answerMap['zipcode'];
      if (zip_answer) {
        this.emitSaveAnswer(Object.assign({}, zip_answer), address['postal_code'].long);
      }
    }
  }
  updateJson(place) {
    const json_answer = this.answerMap['address_json'];
    if (json_answer) {
      this.emitSaveAnswer(Object.assign({}, json_answer), JSON.stringify(place));
    }
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-address-group", { answers: this.answers, label: this.label, labelledBy: this.labelledBy });
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-address-group__container" }, h("div", { class: "bp-sdk-address-group__streets" }, h("div", { class: "bp-sdk-row" }, this.answerMap['street_1'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group-street-primary", labelledBy: this.labelledBy, shouldHideLabel: bL(this.label, this.answerMap['street_1']), answer: this.answerMap['street_1'] })), this.answerMap['street_2'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group-street-secondary", labelledBy: this.labelledBy, shouldHideLabel: bL(this.label, this.answerMap['street_2']), answer: this.answerMap['street_2'] })))), h("div", { class: "bp-sdk-address-group__locality" }, h("div", { class: "bp-sdk-row" }, this.answerMap['city'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group__city", labelledBy: this.labelledBy, shouldHideLabel: bL(this.label, this.answerMap['city']), answer: this.answerMap['city'] })), this.answerMap['state'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group__state", labelledBy: this.labelledBy, shouldHideLabel: bL(this.label, this.answerMap['state']), answer: this.answerMap['state'], useSelectAlias: true })), this.answerMap['zipcode'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group__zipcode", labelledBy: this.labelledBy, shouldHideLabel: bL(this.label, this.answerMap['zipcode']), answer: this.answerMap['zipcode'] })))), this.answerMap['address_json'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group-address__json", labelledBy: this.labelledBy, shouldHideLabel: bL(this.label, this.answerMap['address_json']), answer: this.answerMap['address_json'], hidden: true }))));
  }
  static get watchers() { return {
    "answers": ["onAnswersChange"]
  }; }
};
BpSdkAddressGroup.style = bpSdkAddressGroupCss;

const bpSdkCoverageGroupCss = "";

const BpSdkCoverageGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.questionGroup = undefined;
    this.useExternal = false;
  }
  resetState() { }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-coverage-group');
    customElements.whenDefined('bp-sdk-external-coverage-group').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-coverage-group", { questionGroup: this.questionGroup });
  }
  renderAnswer(answer) {
    var _a;
    const nestedGroupToRender = (_a = this.questionGroup.nestedGroupsWithAnswers) === null || _a === void 0 ? void 0 : _a.get(answer.id);
    return [
      !nestedGroupToRender && h("bp-sdk-dynamic-input-redux-container", { answer: answer, id: `bp-sdk-question-group__${answer.question.id}` }),
      nestedGroupToRender && h("bp-sdk-question-group-container", { questionGroup: nestedGroupToRender }),
    ];
  }
  renderInternal() {
    var _a, _b, _c;
    return (h("div", { class: "bp-sdk-coverage-group__container" }, h("bp-sdk-question-group-label", { labelId: (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.groupId, label: (_b = this.questionGroup) === null || _b === void 0 ? void 0 : _b.parentQuestionAnswer.question.text }), (_c = this.questionGroup) === null || _c === void 0 ? void 0 :
      _c.answers.map((answer) => this.renderAnswer(answer))));
  }
};
BpSdkCoverageGroup.style = bpSdkCoverageGroupCss;

const bpSdkDriverQuestionPoolContainerCss = "";

const BpSdkDriverQuestionPoolContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.deletePool = createEvent(this, "deletePool", 7);
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.mapDispatchToProps(this, { removeQuestionPool });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        applicationId: getFormId(state),
        config: getPartnerEngineConfig(state),
        questionSets: getQuestionSets(state),
      };
    };
    this.handleDeleteItem = () => {
      this.isDeleting = true;
      this.removeQuestionPool({
        answer_pool_id: this.questionPoolId,
        application_id: this.applicationId,
        config: this.config,
        callback: () => {
          this.deletePool.emit(undefined);
        },
      });
      this.deletePool.emit(this.questionPoolId);
    };
    this.questionGroup = undefined;
    this.applicationId = undefined;
    this.config = undefined;
    this.questionSets = [];
    this.useExternal = false;
    this.questionPool = undefined;
    this.questionPoolId = undefined;
    this.isDeleting = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onQuestionGroupChange(questionGroup) {
    this.questionPoolId = questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.poolId;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-driver-question-pool-container');
    customElements.whenDefined('bp-sdk-external-driver-question-pool-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.onQuestionGroupChange(this.questionGroup);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-driver-question-pool-container", { applicationId: this.applicationId, config: this.config, questionGroup: this.questionGroup, questionSets: this.questionSets }));
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-driver-question-pool-container__container" }, !this.isDeleting && !!this.questionPoolId && (h("bp-sdk-driver-group", { group: this.questionGroup, canDelete: true, onDeleteItem: this.handleDeleteItem }))));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "questionGroup": ["onQuestionGroupChange"]
  }; }
};
BpSdkDriverQuestionPoolContainer.style = bpSdkDriverQuestionPoolContainerCss;

const bpSdkQuestionGroupLabelCss = "";

const BpSdkQuestionGroupLabel = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.labelId = undefined;
    this.label = undefined;
    this.useExternal = false;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-question-group-label');
    customElements.whenDefined('bp-sdk-external-question-group-label').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-question-group-label", { label: this.label, labelId: this.labelId });
  }
  renderInternal() {
    return (h("h2", { id: this.labelId, class: "bp-sdk-question-group__label" }, this.label));
  }
};
BpSdkQuestionGroupLabel.style = bpSdkQuestionGroupLabelCss;

const bpSdkStepperGroupCss = "";

const BpSdkStepperGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.questionGroup = undefined;
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-stepper-group');
    customElements.whenDefined('bp-sdk-external-stepper-group').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderAnswers(questionGroup) {
    var _a;
    return (_a = questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.answers) === null || _a === void 0 ? void 0 : _a.map((answer) => {
      if (this.displayAsQuestionGroup(answer.id)) {
        const nestedGroup = this.questionGroup.nestedGroupsWithAnswers.get(answer.id);
        if (nestedGroup.answers.length > 0) {
          return h("bp-sdk-stepper-group", { questionGroup: nestedGroup });
        }
        return h("bp-sdk-stepper-group", { questionGroup: this.questionGroup.nestedGroupsWithAnswers.get(answer.id) });
      }
      else {
        return (h("bp-sdk-dynamic-input-redux-container", { answer: answer, labelledBy: "", id: `bp-sdk-question-group__${answer.question.id}`, class: "bp-sdk-question-group__question-set" }));
      }
    });
  }
  renderExternal() {
    return h("bp-sdk-external-stepper-group", { questionGroup: this.questionGroup });
  }
  renderInternal() {
    return h("div", { class: "bp-sdk-stepper-group__container" }, this.renderAnswers(this.questionGroup));
  }
  displayAsQuestionGroup(id) {
    return this.questionGroup.nestedGroupsWithAnswers.has(id);
  }
};
BpSdkStepperGroup.style = bpSdkStepperGroupCss;

const bpSdkStepperGroupButtonCss = "";

const BpSdkStepperGroupButton = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.answer = undefined;
    this.direction = undefined;
    this.buttonDisabled = false;
    this.handleStepperButtonClick = undefined;
    this.useExternal = false;
  }
  resetState() { }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-stepper-group-button');
    customElements.whenDefined('bp-sdk-external-stepper-group-button').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-stepper-group-button", { answer: this.answer, direction: this.direction, buttonDisabled: this.buttonDisabled, handleStepperButtonClick: this.handleStepperButtonClick }));
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-stepper-group-button__container" }, this.answer && (h("button", { type: "button", class: "bp-sdk-stepper-group-button__button", disabled: this.buttonDisabled, onClick: () => this.handleStepperButtonClick(this.answer, this.direction) }, this.answer.question.text))));
  }
};
BpSdkStepperGroupButton.style = bpSdkStepperGroupButtonCss;

const bpSdkStepperGroupContainerCss = "";

const BpSdkStepperGroupContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.handleStepperClick = (answerId) => {
      const index = this.questionGroup.answers.findIndex((answer) => answer.id === answerId);
      this.currentActiveStepper = index >= 0 ? index : 0;
    };
    this.handleButtonClick = (answerId, direction) => {
      if (direction === 'forward') {
        this.currentActiveStepper += 1;
      }
      else {
        this.currentActiveStepper -= 1;
      }
    };
    this.questionGroup = undefined;
    this.currentActiveStepper = 0;
    this.currentActiveStepperId = undefined;
    this.previousStep = null;
    this.nextStep = null;
    this.buttonDisable = false;
    this.useExternal = false;
  }
  onCurrentActiveStepChange(index) {
    var _a, _b, _c, _d, _e, _f;
    this.currentActiveStepperId = (_b = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.answers[index]) === null || _b === void 0 ? void 0 : _b.id;
    this.previousStep = (_d = (_c = this.questionGroup) === null || _c === void 0 ? void 0 : _c.answers[index - 1]) !== null && _d !== void 0 ? _d : null;
    this.nextStep = (_f = (_e = this.questionGroup) === null || _e === void 0 ? void 0 : _e.answers[index + 1]) !== null && _f !== void 0 ? _f : null;
    this.updateButtonDisabled();
  }
  onQuestionGroupChange(questionGroup) {
    var _a, _b;
    if (!!questionGroup) {
      this.currentActiveStepperId = (_b = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.answers[this.currentActiveStepper]) === null || _b === void 0 ? void 0 : _b.id;
      this.updateButtonDisabled();
    }
  }
  resetState() {
    var _a, _b;
    this.currentActiveStepper = 0;
    this.previousStep = null;
    this.nextStep = (_b = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.answers[this.currentActiveStepper + 1]) !== null && _b !== void 0 ? _b : null;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-stepper-group-container');
    customElements.whenDefined('bp-sdk-external-stepper-group-container').then(() => {
      this.useExternal = true;
    });
    this.onCurrentActiveStepChange(this.currentActiveStepper);
    this.onQuestionGroupChange(this.questionGroup);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderCurrentQuestionGroup(currentActiveStepperId) {
    var _a;
    const currentGroup = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.nestedGroupsWithAnswers.get(currentActiveStepperId);
    return (h("div", { class: "bp-sdk-stepper-group-container__current-group" }, h("bp-sdk-stepper-group", { questionGroup: currentGroup })));
  }
  renderExternal() {
    return h("bp-sdk-external-stepper-group-container", { questionGroup: this.questionGroup });
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-stepper-group-container__container" }, this.renderCurrentQuestionGroup(this.currentActiveStepperId), h("bp-sdk-stepper-group-button", { answer: this.previousStep, direction: "backward", buttonDisabled: false, handleStepperButtonClick: this.handleButtonClick }), h("bp-sdk-stepper-group-button", { answer: this.nextStep, direction: "forward", buttonDisabled: this.buttonDisable, handleStepperButtonClick: this.handleButtonClick })));
  }
  updateButtonDisabled() {
    var _a;
    if (!!this.currentActiveStepperId) {
      const group = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.nestedGroupsWithAnswers.get(this.currentActiveStepperId);
      const aggregateAnswers = [
        ...group.answers,
        ...group.answers.filter((answer) => {
          if (group.nestedGroupsWithAnswers.has(answer.id)) {
            return group.nestedGroupsWithAnswers.get(answer.id).answers;
          }
        }),
      ];
      this.buttonDisable = !aggregateAnswers.every((answer) => { var _a; return !!answer.choice_id || ((_a = answer.choice_ids) === null || _a === void 0 ? void 0 : _a.length) > 0 || !!answer.value || !answer.required || answer.display_type === 'private'; });
    }
  }
  static get watchers() { return {
    "currentActiveStepper": ["onCurrentActiveStepChange"],
    "questionGroup": ["onQuestionGroupChange"]
  }; }
};
BpSdkStepperGroupContainer.style = bpSdkStepperGroupContainerCss;

const bpSdkVehicleQuestionPoolContainerCss = "";

const BpSdkVehicleQuestionPoolContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.deletePool = createEvent(this, "deletePool", 7);
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.mapDispatchToProps(this, { removeQuestionPool });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        applicationId: getFormId(state),
        config: getPartnerEngineConfig(state),
      };
    };
    this.handleDeleteItem = () => {
      this.isDeleting = true;
      this.removeQuestionPool({
        answer_pool_id: this.questionPoolId,
        application_id: this.applicationId,
        config: this.config,
        callback: () => {
          this.deletePool.emit(undefined);
        },
      });
      this.deletePool.emit(this.questionPoolId);
    };
    this.questionGroup = undefined;
    this.applicationId = undefined;
    this.config = undefined;
    this.useExternal = false;
    this.questionPool = undefined;
    this.questionPoolId = undefined;
    this.isDeleting = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onQuestionGroupChange(questionGroup) {
    this.questionPoolId = questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.poolId;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-question-pool-container');
    customElements.whenDefined('bp-sdk-external-vehicle-question-pool-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.onQuestionGroupChange(this.questionGroup);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-vehicle-question-pool-container", { applicationId: this.applicationId, config: this.config, questionGroup: this.questionGroup }));
  }
  renderInternal() {
    return (!this.isDeleting &&
      !!this.questionPoolId && (h("bp-sdk-vehicle-panel-container", { canDelete: true, isVehicleTrailer: d9(this.questionGroup), onDeleteItem: this.handleDeleteItem, questionGroup: this.questionGroup, answers: Q9(this.questionGroup), shouldShowTrailers: this.questionGroup.order >= 1 || d9(this.questionGroup) })));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "questionGroup": ["onQuestionGroupChange"]
  }; }
};
BpSdkVehicleQuestionPoolContainer.style = bpSdkVehicleQuestionPoolContainerCss;

export { BpSdkAccordion as bp_sdk_accordion, BpSdkAccumulationQuestionGroup as bp_sdk_accumulation_question_group, BpSdkAccumulationQuestionGroupContainer as bp_sdk_accumulation_question_group_container, BpSdkAddressGroup as bp_sdk_address_group, BpSdkCoverageGroup as bp_sdk_coverage_group, BpSdkDriverQuestionPoolContainer as bp_sdk_driver_question_pool_container, BpSdkQuestionGroupLabel as bp_sdk_question_group_label, BpSdkStepperGroup as bp_sdk_stepper_group, BpSdkStepperGroupButton as bp_sdk_stepper_group_button, BpSdkStepperGroupContainer as bp_sdk_stepper_group_container, BpSdkVehicleQuestionPoolContainer as bp_sdk_vehicle_question_pool_container };
